@@ -342,7 +342,7 @@ def triangle(LB, UB, natoms):
                         raise ValueError('Bounds Incorrect.')
     return LL, UL
 
-def metrize(LB, UB, natoms, seed=False, non_triangle=False, debug=False):
+def metrize(LB, UB, natoms, non_triangle=False, debug=False):
     """metrize
     Metrization selects random in-range distances. Copied from ref [2], pp. 253-254.
     Scales O(N^3). 
@@ -355,18 +355,12 @@ def metrize(LB, UB, natoms, seed=False, non_triangle=False, debug=False):
             Upper bounds matrix.
         natoms : int
             Number of atoms in the molecule.
-        seed : bool, optional
-            Flag for random number seed. Default is False.
         
     Returns
     -------
         D : np.array
             Distance matrix.  
     """
-    if seed:
-        if debug:
-            print('Seed met:, ',seed)
-        np.random.seed(seed)
     D = np.zeros((natoms, natoms))
     LB, UB = triangle(LB, UB, natoms)
     for i in range(natoms-1):
@@ -589,7 +583,7 @@ def detect_cps(OBMol, ligcoordList):
         list of lists of the corecoordList indices shared by each ring
     """
     # Are there sets of coordinating atoms that are given in inputs? - based on if list passed
-    multiflag_lig_con_sets = np.array([','.join([str(y) for y in sorted(x[1])]) for x in ligcoordList if isinstance(x[1],list)])
+    multiflag_lig_con_sets = np.array([','.join([str(y) for y in sorted(x[1])]) for x in ligcoordList if isinstance(x[1],(list,np.ndarray))])
     isCp = False
     cp_rings = []
     shared_coords = []
@@ -612,7 +606,6 @@ def detect_cps(OBMol, ligcoordList):
                         shared_coords.append([int(x) for x in shared.split(',')])
         else:
             # Flag sets of coordination indices
-            multiflag_lig_coords = np.array([x[0] for x in ligcoordList if isinstance(x[1],list)])
             rings = OBMol.GetSSSR()
             for ring in rings:
                 if all([ring.IsInRing(int(x)+1) for x in multiflag_lig_coords]):
@@ -1108,7 +1101,6 @@ def set_position_align(ase_atoms, ligcoordList, corecoordList, isCp=False, debug
                 inds = np.arange(0,len(ideal),1)
                 orderings = np.array([np.array(x) for x in itertools.permutations(inds,len(inds))])
                 if len(orderings) > 100:
-                    np.random.seed(42)
                     ordering_inds = np.random.choice(np.arange(0,len(orderings),1),100)
                     orderings = orderings[ordering_inds]
                 r = []
@@ -1179,7 +1171,7 @@ def set_position_align(ase_atoms, ligcoordList, corecoordList, isCp=False, debug
     return (rotatedConformer, minval, sane)
 
 def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe', 
-                          seed=42,add_angle_constraints=True, non_triangle=False,
+                          add_angle_constraints=True, non_triangle=False,
                           rot_coord_vect=False, rot_angle=0, skip_mmff=False,
                           covrad_metal=None, vdwrad_metal=None, no_ff=False,
                           debug=False
@@ -1196,8 +1188,6 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
         List of lists inidicated connection sites by geometry 
     metal : str, optional
         Metal to be calculated -> by default, Fe
-    seed : str, optional 
-        random seed to be used for ligand generation.
     covrad_metal : float, optional
         covalent radii of the metal, default None
     vdwrad_metal : float, optional
@@ -1215,6 +1205,8 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
         rotational loss for the ligand atoms to the coordination sites.
     """
     Conf3D =  io_obabel.get_obmol_smiles(ligsmiles, addHydrogens=True)
+    # Detect Cp rings - move before adding metal center.
+    isCp, cp_rings, shared_coords = detect_cps(Conf3D, ligcoordList)
     catoms = [x[0] for x in ligcoordList]
     # Calc charges from total charge from OBmol
     init_charges_lig = np.zeros(Conf3D.NumAtoms())
@@ -1227,8 +1219,6 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
     allcoords, anums, graph = io_obabel.get_OBMol_coords_anums_graph(Conf3D)
     bo_dict, atypes = io_obabel.get_OBMol_bo_dict_atom_types(Conf3D)
     init_charges_lig[0] = Conf3D.GetTotalCharge()
-    # Detect Cp rings
-    isCp, cp_rings, shared_coords = detect_cps(Conf3D, ligcoordList)
     cp_catoms = []
     if isCp:
         ligcoordList, corecoordList, cp_catoms, catoms = manage_cps(Conf3D, cp_rings, 
@@ -1272,7 +1262,6 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
     # Here, I start with tighter constraints and loosen them to get to a final conformer.
     shape = get_ideal_angles(core_vects)
     status = False
-    tseeds = [x+1 for x in range(200)] # Do 200 at most.
     count = 0
     fail_gen = False
     LB, UB = get_bounds_matrix(allcoords, graph, natoms, 
@@ -1284,7 +1273,7 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
         try:
             tLB = LB.copy()
             tUB = UB.copy()
-            D = metrize(tLB, tUB, natoms, seed=(tseeds[count]+seed), non_triangle=non_triangle,debug=debug)
+            D = metrize(tLB, tUB, natoms, non_triangle=non_triangle,debug=debug)
             D0 = get_cm_dists(D, natoms)
             G = get_metric_matrix(D, D0, natoms)
             L, V = get_3_eigs(G, natoms)
@@ -1303,7 +1292,6 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
     if fail_gen:
         if debug:
             print('Trying More Dist Geom with 0.2 Bond Tol LB and Loosened Metal_Center Constraints.')
-        tseeds = [x+1 for x in range(200)] # Do 200 at most.
         status = False
         count = 0
         LB, UB = get_bounds_matrix(allcoords, graph, natoms, 
@@ -1316,7 +1304,7 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
             try:
                 tLB = LB.copy()
                 tUB = UB.copy()
-                D = metrize(tLB, tUB, natoms, seed=(tseeds[count]+seed+1), non_triangle=non_triangle,debug=debug)
+                D = metrize(tLB, tUB, natoms, non_triangle=non_triangle,debug=debug)
                 D0 = get_cm_dists(D, natoms)
                 G = get_metric_matrix(D, D0, natoms)
                 L, V = get_3_eigs(G, natoms)
@@ -1328,8 +1316,9 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
                 
             if np.any(np.isnan(X)): # If any are not nan continue!
                 if debug:
-                    print('V: ',V, 'L: ', L, 'X: ',X)
-                if count > (len(tseeds)-1):
+                    # print('V: ',V, 'L: ', L, 'X: ',X)
+                    print('DG iteration passing.')
+                if count > 200:
                     fail_gen = True
                     status = True
                 else:
@@ -1340,7 +1329,6 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
     if fail_gen:
         if debug:
             print('Trying More Dist Geom with 0.2 Bond Tol LB, 0.2 Angle tol LB, and Loosened Metal_Center Constraints')
-        tseeds = [x+1 for x in range(200)] # Do 400 at most.
         status = False
         count = 0
         LB, UB = get_bounds_matrix(allcoords, graph, natoms, 
@@ -1354,7 +1342,7 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
             try:
                 tLB = LB.copy()
                 tUB = UB.copy()
-                D = metrize(tLB, tUB, natoms, seed=(tseeds[count]+seed+1), non_triangle=non_triangle,debug=debug)
+                D = metrize(tLB, tUB, natoms, non_triangle=non_triangle,debug=debug)
                 D0 = get_cm_dists(D, natoms)
                 G = get_metric_matrix(D, D0, natoms)
                 L, V = get_3_eigs(G, natoms)
@@ -1366,8 +1354,9 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
                 
             if np.any(np.isnan(X)): # If any are not nan continue!
                 if debug:
-                    print('V: ',V, 'L: ', L, 'X: ',X)
-                if count > (len(tseeds)-1):
+                    # print('V: ',V, 'L: ', L, 'X: ',X)
+                    print('DG iteration passing.')
+                if count > 200:
                     fail_gen = True
                     status = True
                 else:
@@ -1385,14 +1374,13 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
                 h_bond_tol=0.1, h_angle_tol=0.2,
                 isCp=isCp, cp_catoms=cp_catoms,
                 add_angle_constraints=add_angle_constraints)
-        tseeds = [x+1 for x in range(200)] # Do 400 at most.
         status = False
         count = 0
         while not status:
             try:
                 tLB = LB.copy()
                 tUB = UB.copy()
-                D = metrize(tLB, tUB, natoms, seed=(tseeds[count]+seed+1), non_triangle=non_triangle, debug=debug)
+                D = metrize(tLB, tUB, natoms, non_triangle=non_triangle, debug=debug)
                 D0 = get_cm_dists(D, natoms)
                 G = get_metric_matrix(D, D0, natoms)
                 L, V = get_3_eigs(G, natoms)
@@ -1404,8 +1392,9 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
                 
             if np.any(np.isnan(X)): # If any are not nan continue!
                 if debug:
-                    print('V: ',V, 'L: ', L, 'X: ',X)
-                if count > (len(tseeds)-1):
+                    # print('V: ',V, 'L: ', L, 'X: ',X)
+                    print('DG iteration passing.')
+                if count > 200:
                     fail_gen = True
                     status = True
                 else:
@@ -1423,14 +1412,13 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
                                     h_bond_tol=0.1, h_angle_tol=0.3,
                                     isCp=isCp, cp_catoms=cp_catoms,
                                     add_angle_constraints=add_angle_constraints)
-        tseeds = [x+1 for x in range(200)] # Do 400 at most.
         status = False
         count = 0
         while not status:
             try:
                 tLB = LB.copy()
                 tUB = UB.copy()
-                D = metrize(tLB, tUB, natoms, seed=(tseeds[count]+seed+1), non_triangle=non_triangle, debug=debug)
+                D = metrize(tLB, tUB, natoms, non_triangle=non_triangle, debug=debug)
                 D0 = get_cm_dists(D, natoms)
                 G = get_metric_matrix(D, D0, natoms)
                 L, V = get_3_eigs(G, natoms)
@@ -1442,8 +1430,9 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
                 
             if np.any(np.isnan(X)): # If any are not nan continue!
                 if debug:
-                    print('V: ',V, 'L: ', L, 'X: ',X)
-                if count > (len(tseeds)-1):
+                    # print('V: ',V, 'L: ', L, 'X: ',X)
+                    print('DG iteration passing.')
+                if count > 200:
                     fail_gen = True
                     status = True
                 else:
@@ -1462,7 +1451,7 @@ def get_aligned_conformer(ligsmiles, ligcoordList, corecoordList, metal='Fe',
         if np.any(np.isnan(res1)):
             if debug:
                 print('Dist Geom produced Nan. - Skipping!')
-            Conf3D_out = io_obabel.convert_obmol_ase(Conf3D,add_hydrogens=add_hydrogens)
+            Conf3D_out = io_obabel.convert_obmol_ase(Conf3D, add_hydrogens=add_hydrogens)
             final_relax = False
             fail = True
             tligcoordList = ligcoordList.copy()
@@ -1573,29 +1562,32 @@ def find_conformers(ligsmiles, ligcoordList, corecoordList, metal='Fe', nconform
         list of ase atoms objects.
     val_list : list
         list of values of the conformers to match the rotation of the coordination sites.
+    rot_list : list
+        list of rotations applied the ligands in degrees.
     """
     if debug:
         print('DEBUG LIGANDS:',ligsmiles, ligcoordList, corecoordList, metal) #for debug
     conf_list = []
     val_list = []
     tligcoordList_out = []
-    master_seed = 42
-    np.random.seed(master_seed)
-    seeds = [np.random.randint(1,100) for x in range(nconformers)]
+    rot_list = []
+    
     if debug:
-        print('Init seeds: ', seeds)
+        seeds = [np.random.randint(1,100) for x in range(nconformers)]
+        print('Init seeds (pre-ligand generation): ', seeds)
     OBmol_lig = io_obabel.get_obmol_smiles(ligsmiles)
 
     if (OBmol_lig.NumAtoms() < 4): # Limit smaller molecules conformers (not useful)
         conf, val, sane, final_relax, bo_dict, atypes, tligcoordList = get_aligned_conformer(ligsmiles, ligcoordList, 
                                          corecoordList, 
-                                         metal=metal, seed=seeds[0],
+                                         metal=metal,
                                          skip_mmff=skip_mmff, covrad_metal=covrad_metal,
                                          vdwrad_metal=vdwrad_metal,no_ff=no_ff,debug=debug)
         if sane:
             conf_list.append(conf)
             val_list.append(val)
             tligcoordList_out.append(tligcoordList)
+            rot_list.append(0)
         else:
             if debug:
                 print('Failed sanity checks after rotation!')
@@ -1604,13 +1596,14 @@ def find_conformers(ligsmiles, ligcoordList, corecoordList, metal='Fe', nconform
             print('Generating cis/mer/facs')
         conf, val, sane, final_relax, bo_dict, atypes, tligcoordList = get_aligned_conformer(ligsmiles, ligcoordList, 
                                          corecoordList, 
-                                         metal=metal, seed=seeds[0],
+                                         metal=metal,
                                          skip_mmff=skip_mmff,covrad_metal=covrad_metal,
                                          vdwrad_metal=vdwrad_metal,no_ff=no_ff,debug=debug)
         if sane:
             conf_list.append(conf)
             val_list.append(val)
             tligcoordList_out.append(tligcoordList)
+            rot_list.append(0)
         else:
             if debug:
                 print('Failed sanity checks after rotation!')
@@ -1618,29 +1611,30 @@ def find_conformers(ligsmiles, ligcoordList, corecoordList, metal='Fe', nconform
             print('Generating cis/mer/facs.')
         conf, val, sane, final_relax, bo_dict, atypes, tligcoordList = get_aligned_conformer(ligsmiles, ligcoordList, 
                                          corecoordList, 
-                                         metal=metal, seed=seeds[2],
+                                         metal=metal,
                                          skip_mmff=True, covrad_metal=covrad_metal,
                                          vdwrad_metal=vdwrad_metal,no_ff=no_ff,debug=debug)
         if sane:
             conf_list.append(conf)
             val_list.append(val)
             tligcoordList_out.append(tligcoordList)
+            rot_list.append(0)
         else:
             if debug:
                 print('Failed sanity checks after rotation!')
         
         # Limit conformers for bidentate cis/tri_mer/tri_fac -> generate rotated/flipped versions!!!
         # for i in range(1):
-        seed = seeds[1]
         conf, val, sane, final_relax, bo_dict, atypes, tligcoordList = get_aligned_conformer(ligsmiles, ligcoordList, 
                                         corecoordList, 
-                                        metal=metal, seed=seed,
+                                        metal=metal, 
                                         skip_mmff=skip_mmff, covrad_metal=covrad_metal,
                                          vdwrad_metal=vdwrad_metal,no_ff=no_ff,debug=debug)
         if sane:
             conf_list.append(conf)
             val_list.append(val)
             tligcoordList_out.append(tligcoordList)
+            rot_list.append(0)
         else:
             if debug:
                 print('Failed sanity checks after rotation!')
@@ -1648,7 +1642,7 @@ def find_conformers(ligsmiles, ligcoordList, corecoordList, metal='Fe', nconform
         # Add N+1 without the explicit angle constraints
         conf, val, sane, final_relax, _ , _, tligcoordList = get_aligned_conformer(ligsmiles, ligcoordList, 
                                             corecoordList, 
-                                            metal=metal, seed=master_seed, 
+                                            metal=metal, 
                                             add_angle_constraints=False,
                                             skip_mmff=skip_mmff, covrad_metal=covrad_metal,
                                             vdwrad_metal=vdwrad_metal,no_ff=no_ff,debug=debug)
@@ -1656,11 +1650,12 @@ def find_conformers(ligsmiles, ligcoordList, corecoordList, metal='Fe', nconform
             conf_list.append(conf)
             val_list.append(val)
             tligcoordList_out.append(tligcoordList)
+            rot_list.append(0)
         
         # Add N+2 without the triangle angle constraint for metal (encouraging different conformers for multidentate)
         conf, val, sane, final_relax, _, _, tligcoordList = get_aligned_conformer(ligsmiles, ligcoordList, 
                                             corecoordList, 
-                                            metal=metal, seed=master_seed, 
+                                            metal=metal, 
                                             add_angle_constraints=True,
                                             non_triangle=True,
                                             skip_mmff=skip_mmff, covrad_metal=covrad_metal,
@@ -1669,11 +1664,12 @@ def find_conformers(ligsmiles, ligcoordList, corecoordList, metal='Fe', nconform
             conf_list.append(conf)
             val_list.append(val)
             tligcoordList_out.append(tligcoordList)
+            rot_list.append(0)
 
         # Add N+2 without the triangle angle constraint for metal (encouraging different conformers for multidentate)
         conf, val, sane, final_relax, _, _, tligcoordList = get_aligned_conformer(ligsmiles, ligcoordList, 
                                             corecoordList, 
-                                            metal=metal, seed=master_seed, 
+                                            metal=metal,  
                                             add_angle_constraints=False,
                                             non_triangle=True,
                                             skip_mmff=skip_mmff, covrad_metal=covrad_metal,
@@ -1682,18 +1678,19 @@ def find_conformers(ligsmiles, ligcoordList, corecoordList, metal='Fe', nconform
             conf_list.append(conf)
             val_list.append(val)
             tligcoordList_out.append(tligcoordList)
+            rot_list.append(0)
     else:
         for i in range(nconformers):
-            seed = seeds[i]
             conf, val, sane, final_relax, bo_dict, atypes, tligcoordList = get_aligned_conformer(ligsmiles, ligcoordList, 
                                             corecoordList, 
-                                            metal=metal, seed=seed,
+                                            metal=metal, 
                                             skip_mmff=skip_mmff, covrad_metal=covrad_metal,
                                             vdwrad_metal=vdwrad_metal,no_ff=no_ff,debug=debug)
             if sane:
                 conf_list.append(conf)
                 val_list.append(val)
                 tligcoordList_out.append(tligcoordList)
+                rot_list.append(0)
             else:
                 if debug:
                     print('Failed sanity checks after rotation!')
@@ -1701,7 +1698,7 @@ def find_conformers(ligsmiles, ligcoordList, corecoordList, metal='Fe', nconform
         # Add N+1 without the explicit angle constraints
         conf, val, sane, final_relax, _ , _, tligcoordList = get_aligned_conformer(ligsmiles, ligcoordList, 
                                             corecoordList, 
-                                            metal=metal, seed=master_seed, 
+                                            metal=metal, 
                                             add_angle_constraints=False,
                                             skip_mmff=skip_mmff, covrad_metal=covrad_metal,
                                             vdwrad_metal=vdwrad_metal,no_ff=no_ff,debug=debug)
@@ -1709,25 +1706,27 @@ def find_conformers(ligsmiles, ligcoordList, corecoordList, metal='Fe', nconform
             conf_list.append(conf)
             val_list.append(val)
             tligcoordList_out.append(tligcoordList)
+            rot_list.append(0)
         
         # print('Add conformer with no MMFF relaxation')
         conf, val, sane, final_relax, bo_dict, atypes, tligcoordList = get_aligned_conformer(ligsmiles, ligcoordList, 
                                          corecoordList, 
-                                         metal=metal, seed=seeds[2],
+                                         metal=metal, 
                                          skip_mmff=True, covrad_metal=covrad_metal,
                                          vdwrad_metal=vdwrad_metal,no_ff=no_ff,debug=debug)
         if sane:
             conf_list.append(conf)
             val_list.append(val)
             tligcoordList_out.append(tligcoordList)
+            rot_list.append(0)
         else:
             if debug:
                 print('Failed sanity checks after rotation!')
         
-        # Add N+2 without the triangle angle constraint for metal (encouraging different conformers for multidentate)
+        # Add N+2 with the triangle angle constraint for metal (encouraging different conformers for multidentate)
         conf, val, sane, final_relax, _, _, tligcoordList = get_aligned_conformer(ligsmiles, ligcoordList, 
                                             corecoordList, 
-                                            metal=metal, seed=master_seed, 
+                                            metal=metal, 
                                             add_angle_constraints=True,
                                             non_triangle=True,
                                             skip_mmff=skip_mmff, covrad_metal=covrad_metal,
@@ -1736,11 +1735,12 @@ def find_conformers(ligsmiles, ligcoordList, corecoordList, metal='Fe', nconform
             conf_list.append(conf)
             val_list.append(val)
             tligcoordList_out.append(tligcoordList)
+            rot_list.append(0)
         
         # Add N+2 without the triangle angle constraint for metal (encouraging different conformers for multidentate)
         conf, val, sane, final_relax, _, _, tligcoordList = get_aligned_conformer(ligsmiles, ligcoordList, 
                                             corecoordList, 
-                                            metal=metal, seed=master_seed, 
+                                            metal=metal, 
                                             add_angle_constraints=False,
                                             non_triangle=True,
                                             skip_mmff=skip_mmff, 
@@ -1750,6 +1750,7 @@ def find_conformers(ligsmiles, ligcoordList, corecoordList, metal='Fe', nconform
             conf_list.append(conf)
             val_list.append(val)
             tligcoordList_out.append(tligcoordList)
+            rot_list.append(0)
 
     if (len(ligcoordList) == 1) and (len(conf_list) > 0) and (OBmol_lig.NumAtoms()>1): # Add aligned monodentate and 45 and 90-degree rotated conformers
         conf = conf_list[0]
@@ -1757,15 +1758,18 @@ def find_conformers(ligsmiles, ligcoordList, corecoordList, metal='Fe', nconform
                        rot_coord_vect=True, rot_angle=0)
         conf_list.append(rotatedConformer)
         val_list.append(val_list[0])
+        rot_list.append(0)
         tligcoordList_out.append(tligcoordList_out[0])
         if OBmol_lig.NumAtoms() > 2: # For 3 add rotation versions of the ligands
             rotatedConformer, _ , _ = set_position_align(conf, tligcoordList_out[0], corecoordList, isCp=False, debug=debug,
             rot_coord_vect=True, rot_angle=45)
             conf_list.append(rotatedConformer)
+            rot_list.append(45)
             val_list.append(val_list[0])
             tligcoordList_out.append(tligcoordList_out[0])
             rotatedConformer, _ , _ = set_position_align(conf, tligcoordList_out[0], corecoordList, isCp=False, debug=debug,
             rot_coord_vect=True, rot_angle=90)
+            rot_list.append(90)
             conf_list.append(rotatedConformer)
             val_list.append(val_list[0])
             tligcoordList_out.append(tligcoordList_out[0])
@@ -1778,6 +1782,7 @@ def find_conformers(ligsmiles, ligcoordList, corecoordList, metal='Fe', nconform
             rotatedConformer, _ , _ = set_position_align(conf_copy, tligcoordList_out[i], corecoordList, isCp=False, debug=debug,
                 rot_coord_vect=True, rot_angle=180)
             conf_list.append(rotatedConformer)
+            rot_list.append(180)
             val_list.append(val_list[i])
             tligcoordList_out.append(tligcoordList_out[i])
     # Add in rotated 120 and 240 degree rotated versions of the generated conformers.
@@ -1789,12 +1794,18 @@ def find_conformers(ligsmiles, ligcoordList, corecoordList, metal='Fe', nconform
             rotatedConformer, _ , _ = set_position_align(conf_copy, tligcoordList_out[i], corecoordList, isCp=False, debug=debug,
                 rot_coord_vect=True, rot_angle=120)
             conf_list.append(rotatedConformer)
+            rot_list.append(120)
             val_list.append(val_list[i])
             tligcoordList_out.append(tligcoordList_out[i])
             rotatedConformer, _ , _ = set_position_align(conf_copy, tligcoordList_out[i], corecoordList, isCp=False, debug=debug,
                 rot_coord_vect=True, rot_angle=240)
             conf_list.append(rotatedConformer)
+            rot_list.append(240)
             val_list.append(val_list[i])
             tligcoordList_out.append(tligcoordList_out[i])
+
+    if debug:
+        seeds = [np.random.randint(1,100) for x in range(nconformers)]
+        print('Final seeds (post-ligand generation): ', seeds)
         
-    return conf_list, val_list, tligcoordList_out, final_relax, bo_dict, atypes
\ No newline at end of file
+    return conf_list, val_list, tligcoordList_out, final_relax, bo_dict, atypes, rot_list
\ No newline at end of file
